@@ -98,7 +98,7 @@ class Calendars(BaseRefHierarcy):
         from clndr.models.calendar_shifts_days import Calendar_shifts_days
         from clndr.models.holidays import Holidays
 
-        if self.begindate == None or self.enddate == None:
+        if self.begindate is None or self.enddate is None:
             raise Exception(f'Begindate or EndDate is null.')
 
         with transaction.atomic():
