@@ -229,6 +229,9 @@ class Stack:
     def clear(self):
         self.stack = []
 
+    def extend(self, arr):
+        self.stack.extend(arr)
+
     def pop(self):
         if len(self.stack) < 1:
             return None
@@ -273,7 +276,7 @@ class Stack:
         return Stack(self.stack)
 
     def find(self, function):
-        return [item for item in self.stack if function(item)]
+        return [item for item in self.stack if function(item)].copy()
 
     def exists(self, function):
         return len([item for item in self.stack if function(item)]) > 0
@@ -286,7 +289,7 @@ class Stack:
             logger1.warning('====================================end dump=======================================================================')
 
     def find_one(self, function):
-        res = self.find(function=function)
+        res = self.find(function=function).copy()
         if len(res) == 0:
             # self.print_all()
             raise StackElementNotExist()
