@@ -30,6 +30,7 @@ class LoginRequest(DSRequest):
         from django.forms import model_to_dict
         from kaf_pas.planing.models.status_operation_types import Status_operation_types
         from reports.models.jasper_reports_users import Jasper_reports_users
+        from kaf_pas.planing.models.production_order import Production_orderQuerySet
 
         DSRequest.__init__(self, request)
         data = self.get_data()
@@ -82,21 +83,25 @@ class LoginRequest(DSRequest):
                             if len(workshops) == 0:
                                 workshops = [-1]
 
+                        location_ids = Production_orderQuerySet.get_user_locations(user=user)
                         self.response = dict(
+                            # progresses=[ProgressesManager.getRecord(item) for item in Progresses.objects.filter(user=user)],
                             captionUser=user.get_short_name,
                             chatInfo=LoginRequest.get_chats(user),
+                            CKK_CONFIGURATOR=settings.CKK_CONFIGURATOR,
                             codeGroup="",
+                            DEFAULT_TIMEOUT=settings.DEFAULT_TIMEOUT,
                             dynDataSources=settings.DYNAMIC_CLASS.get_datasources(),
+                            ENABLE_FILE_VIEW=settings.ENABLE_FILE_VIEW,
                             fio=user.get_short_name,
                             frequencyOfPollingUnreadMessages=settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES,
                             isAdmin=user.is_admin,
                             isDevelop=user.is_develop,
                             jsLogDebug=settings.JS_LOG_DEBUG if settings.JS_LOG_DEBUG == 1 else 0,
-                            KOMPAS_INFORMICA_WS=settings.KOMPAS_INFORMICA_WS,
                             KOMPAS_INFORMICA=settings.KOMPAS_INFORMICA,
-                            CKK_CONFIGURATOR=settings.CKK_CONFIGURATOR,
-                            DEFAULT_TIMEOUT=settings.DEFAULT_TIMEOUT,
-                            ENABLE_FILE_VIEW=settings.ENABLE_FILE_VIEW,
+                            KOMPAS_INFORMICA_WS=settings.KOMPAS_INFORMICA_WS,
+                            location_ids=location_ids,
+                            location_ids_suffix='_'.join(map(lambda x: str(x), location_ids)) if location_ids is not None else None,
                             login=login,
                             message_state_delivered_id=Messages_state.message_state_delivered().id,
                             message_state_delivered_name=Messages_state.message_state_delivered().name,
@@ -107,18 +112,17 @@ class LoginRequest(DSRequest):
                             message_state_readed_id=Messages_state.message_state_readed().id,
                             message_state_readed_name=Messages_state.message_state_readed().name,
                             Operations_Plan=settings.OPERATIONS_PLAN.OPERSTYPES,
-                            # progresses=[ProgressesManager.getRecord(item) for item in Progresses.objects.filter(user=user)],
+                            operations_statuses=operations_statuses,
                             status=RPCResponseConstant.statusSuccess,
                             user__color=user.color if user.color is not None and user.color != 'undefined' else 'black',
                             user_full_name=user.get_full_name,
                             user_short_name=user.get_short_name,
+                            userId=user.id,
                             username=user.username,
                             workshops=workshops,
-                            userId=user.id,
                             ws_channel=ws_channel,
                             ws_host=settings.WS_HOST,
                             ws_port=settings.WS_PORT,
-                            operations_statuses=operations_statuses,
                             jasper_reports=[dict(
                                 report=model_to_dict(item.report),
                                 editor_identifier=item.editor_identifier,
