@@ -44,7 +44,7 @@ class CommonManagetWithLookUpFieldsQuerySet(AuditQuerySet):
                     id = self.get_id_tuple(group1)
                     try:
                         if forignFld:
-                            if id == None:
+                            if id is None:
                                 data[key] = None
                             else:
                                 if isinstance(id, list):
