@@ -16,6 +16,7 @@ logger = logging.getLogger(__name__)
 
 progress_deleted = 'Процесс удален.'
 
+
 class ProgressDroped(Exception):
     ...
 
@@ -46,6 +47,76 @@ def managed_progress(qty, user, id, message='Обработано позиций
         raise ex
 
 
+@contextmanager
+def managed_progreses(qty, users, id, message='Обработано позиций', title='Обработано позиций', props=0):
+    progreses = Progreses(id=id, qty=qty, users=users, message=message, title=title, props=props)
+    try:
+        yield progreses
+        progreses.close()
+    except ProgressDroped as ex:
+        progreses.close()
+        if callable(progreses.except_func):
+            progreses.except_func()
+        for progress in progreses.progreses:
+            Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
+        raise ex
+    except Exception as ex:
+        if callable(progreses.except_func):
+            progreses.except_func()
+        exc_info = sys.exc_info()
+        stackTrace = traceback.format_exception(*exc_info)
+        stackTrace = '<br>'.join(stackTrace)
+        stackTrace = f'<pre>{stackTrace}</pre>'
+        del exc_info
+        progreses.sendError(message=str(ex), stackTrace=stackTrace)
+
+        progreses.close()
+        raise ex
+
+
+class Progreses:
+    progreses = None
+
+    def __init__(self, users, id, qty=0, message='Обработано позиций', title='Обработано позиций', label_contents=None, props=0):
+        self.progreses = list(map(lambda user: Progress(id=f'{id}_{user.id}', qty=qty, user=user, message=message, title=title, label_contents=label_contents, props=props), users))
+
+    def step(self):
+        for progress in self.progreses:
+            res = progress.step()
+            if res != 0:
+                return res
+        else:
+            return 0
+
+    def setContentsLabel(self, content):
+        for progress in self.progreses:
+            progress.setContentsLabel(content)
+
+    def setQty(self, qty):
+        for progress in self.progreses:
+            progress.setQty(qty)
+
+    def sendInfo(self, message):
+        for progress in self.progreses:
+            progress.sendInfo(message)
+
+    def sendWarn(self, message):
+        for progress in self.progreses:
+            progress.sendWarn(message)
+
+    def sendError(self, message, stackTrace=None):
+        for progress in self.progreses:
+            progress.sendError(message, stackTrace)
+
+    def sendMessage(self, type, message=None):
+        for progress in self.progreses:
+            progress.sendMessage(type, message)
+
+    def close(self):
+        for progress in self.progreses:
+            progress.close()
+
+
 class Progress:
     progress = None
     pbar = None
@@ -55,6 +126,9 @@ class Progress:
     def __init__(self, user, id, qty=0, message='Обработано позиций', title='Обработано позиций', label_contents=None, props=0):
         from isc_common.auth.models.user import User
 
+        if isinstance(message, tuple):
+            raise Exception(f'{message} is tuple')
+
         self.message = message
         self.title = title
         self.props = props
